/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSystem.h"
#include "HvControlCast.h"
#include "HvMath.h"
#include "HvControlVar.h"
#include "HvControlSlice.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvSignalBiquad.h"
#include "HvControlIf.h"
#include "HvSignalVar.h"
#include "HvControlBinop.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_BB0JP6Nw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fhLSopdh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QTPHIUsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ev5WQv9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6pn2A8zP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qFWS2DQ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Iti7Gp8n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BAY4Xx6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8TWyTIsp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_paeHwkrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ebvC0Yft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e6TtqvBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3KOObcuf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N7ma9iOr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SrkykVPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tjJyKWR6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V3nZqMQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n7IFP61x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MhEMc3QX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LpWF5B37_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mcqJnVFJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dHnShe7E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8BIOTvea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KPRxR4OR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0XjOc7co_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Kh2MDc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1NttCOwx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mFmluKYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9voVsGbB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VFvq76oZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kuWYlw7z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nKzrcsUn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rlAXEQzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KLZFkt1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_02gwnt9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jUuXEKEy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6L3Tk0YE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qFu1H8Sz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yWxC7pKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jdegAp5U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nZWaG0Sl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WePLN3ap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BydsUveT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_55QvWWee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z6NQAC5d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vyXYoIYN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VkhFIC2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zx4KkGTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BYJMAfHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VJ8G2brR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YW8yMnkk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PfIC279O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w1PuNtEF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lgyfrjcz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w76RQVkg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qf3wgSSt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tqHSGLZ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RQKQWOP8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j5fw9CJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rWwsiybV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rICsoGXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aLjeiGpg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UTBGq8H9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mhGHSlvr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nU6mYYxX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_or5sNQB5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZndBQzOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C3DDMJZc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xsvvE6Dw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mCM0oMIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q5s66UoS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ajE05OjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iDii86CS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EJT8xIa2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_juvUl71l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HPnRkE7r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KYvpdSUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9vJsYXoC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zsDpB7Tg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_5tsy2YPj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_s1H8ujZ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZMyAA0Nu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RIm9WHQl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xU0cpkV3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NXlncYPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7nAOPhq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_t4RQwi3x_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xS1w8T28_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ti7mOwvT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3pzpXfrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kXU73YfK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7ZCAFNUB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iTDzfS37_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JRVrIUER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WkWhj9HN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kHeQKnRu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kxHUagxh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rFPl1joS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CwKBr5wI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UyNTGetL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qk2VVR1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OV1QImLD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cSsZDlnI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VCV6dM2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MX52visa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_peodvNee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cbRakVKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_bStcGBVv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_RatXEQmW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KUUCHe2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qCoaz7PQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a3q0Khzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QkUigYau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jxquWIVg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_puIBsQpH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_grVZdjqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_edmFDRgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aYVwncSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XfaR3cO8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BnGmvL2w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p94sIb4u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YXXAhbet_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Co1JiI5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ekYMyycx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5muw85Ng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kDpc5wHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UTWJiret_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bexLDlLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EghjHVQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Cgl28Xox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_alGSqSnk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KYvlK4xE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YkV5sRrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gPcbmv0t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_93f8W3gT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_USqblY4k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YT4tON0n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vfcGsZ2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PPjdmElh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XIvnDMCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZAUiKO9n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wcUnj3Yn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oyTIXFxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o25CJBCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WBb7qTzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3Pps5J4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DAOvudPG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZLpTNqKP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SUgyRgmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DulOxjfW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VfmjWf1N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mi1QstDZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lLPrln45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5PR7m6L5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MdP9W2RT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R3Nvz9Cd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_foLzZOIs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nlaPLtiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Jz3NjMO4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WFPEzQZK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IevL1ztH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MHzHM3VG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y7Q5T5FA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rXTSkifS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_AEjWaokl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_516QChLI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TxLQPW3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bklyk4SR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wmztHwGW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5RVCr3rI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xSSGUxBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ncv591ow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4ASbQY3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5iw15YyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xgxzoAca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YonuoeNU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ueyIGSxm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ddhwMrqS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3wfH1587_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PyInXu4k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_MYcayndF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7RFkO3rH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_34HoSDDg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rSDvy0Uj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jTZLc66v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x3gsY0Qy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YTNKfl03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3xqeelRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s2bkk8e0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K2uk7u7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dRpcNv16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C7aLT0rm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F1aEDSge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KRGikCEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6f2P9hzl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_itR0jaDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P7UDywDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xs2XzYZc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2pmAaALB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PNeXM6AD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RDmVbZbu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q00iL2Vv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sd4mIOSF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B84trSHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pSUzovqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dbkijxjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EeLAMP0S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WH9JeiqB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Ftg0hdLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2of2u6gp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fx8rLeIN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ROR8t6SQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vhxfj5Yp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sYt1YgNC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1k21HgEi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DtFNSR28_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W5doq3iN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X3YIfXV8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rzt8lEAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GKsjYLmx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QCKTM05K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g60vPSSr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YZl0VoDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5bHhNlGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7d5waynl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KJZmUQ2Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ijUmO8Px_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CmZl0two_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ll1y2PHQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dOOgfClx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zxRbpREP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ehOXRCiW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1KQhFmsf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fvzQWExC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Fo67zrVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B2eVSfZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gZrEuUcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Lpvmtq4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Vd5qBP6E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_j8yEDq1X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OEJUfafN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wRidfFLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JbwF3zBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DZ6DaeaI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g3dBtEgo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d2H4RdWj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PEwhR6Kq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tbs4ApX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q1hoGURS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RVV0dQdG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iPvWaGzI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KDY9KDZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Eo4mSVQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BSbvYfz3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3h0B465A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6blOP0JJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cgCP9Gxa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KxODAI8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IXobMh1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6QqPKXIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6JQnKTNy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K4tWkrXb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AI0Ufx84_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_keKi0m7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6GfcFtlE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_t4qetpRc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_pCCBWG3n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GstIRkRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_A6KQz1nW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AO7WGWUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kAPTUHUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2FXBUpQs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dhrfri8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wnp1zetI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yKnaCbyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TZZmRhXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6fYFLwWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l4a0Vn2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ji2Ia90I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eiVvRr6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Me5ZmU5x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sAXUmLO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_07arI7f4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FGz6tUGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GNA0zXFb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pjOAMOgh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fO99uysc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_unOPrTf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CS59JooV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pWFx2WjZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3CzghXcw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PYesE5j4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MsddBMKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_W16EAjpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Oke1MFkf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tYyEf4cP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dK4ccVMU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dsyc77aR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e5gaKPJ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kywEHqLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ngEp4TpG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RdpWOGNS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QQNdvl8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5p8aA6f9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_slicJiGb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hwmlPeEP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_13x8J1XX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HYcIDU6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VmHUe2NM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wXJN9wZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2HVUvVse_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WzsQvwk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C0oLjv1h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jS2Zp3OJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hdPx7RCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sopWmeTm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_roHKA6M9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_k2TyWfMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ffbLk1RN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bfMPTqYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bueAPoJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZIxA2tmj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N9vepiKX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sAx0dcgm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_goIwB27V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_buRj5c35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b9z7ycI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ur48viSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_in0K3npS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IQZONn1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RcEhMT3m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZgWiSWAZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PJxQKi4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lcZRgEj3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5J6iinp2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WkX9kgNf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QacSvONm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ouoJ7IA8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wrkSF9bh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_R8sS3XrI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_o54VlGTh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IgJ9wh5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JG4MMtkk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1euHBnpz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_elAEH122_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_G9OE8a55_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mfQdcfnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9NqkFmbS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_74SPRDJo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xCMSN9Ih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Gp5uQk9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZRXwf9Zc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_1yEFjZ9r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5cCtaX1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_4u6e12ar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yfxDfJ2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GlaP3VsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xS8IZq5X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aft7nbXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HFD9fbJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AcnAAEHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TWOYyJG8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hpQBWSpT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NIKD0Bjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N0aJ8teY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mjMQ6z4B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UNDleA4k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qy5461F5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GmwGwTXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_iCxwBcXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5R53mgWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6CyLorIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6R1KMUEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UopGuIto_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HojHfGnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZD0IWTwI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RJWn1Wcq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r4SG2tIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zOvpUr1w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zyakin4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1waI4bcL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hHZ0kApF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zgah5LHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g6uRnAzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gQTzEXHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BZVqZU9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ol1yy08i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UQ379Pue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rtVK20Rs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Wt08C07y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iKRhgUWJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zG5qIPVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Sxz0e2e9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z1bzD1VI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A99RM9qn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yXJef9Rk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A5y6779A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bRpopLAG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jaawctk1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JvJSpfRx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LCc9HjJo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zR6MhPDs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z9yXpz8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y5ZckQ96_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NcQWEOhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_umsEixI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GtzHCqQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BxRdrddP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1FpMruBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wfnJH2eB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wO5AT3v3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kLbXaott_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JmzMJuyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Tnwhru76_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qps8kAsf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TXpoxYK2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wyF5LWgd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iIBsJlGl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cvsMdzpw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_JMFCi2LS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iU1WFYNv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Zrvatyt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lUNT4PhC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9o7cIUrA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g9QYfcyF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4LqAD9cO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4vQ5V7P3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ryeIGNvs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YDGc2Op0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wDRRzTWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_faNuLKx1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zgy6nCoI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e33qDf3R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6WaVr1Tt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lQGcOHVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mo84UlDG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2hlHocoN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0ZvHsNxO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gO4zWVKS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ToZB1YKY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kl1Vefm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_SkdXNZGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6TBT06PP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_z1GALwbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AQDDEjRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bJYqLAcv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_91L1OIiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kh3sxpq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qiRtAgbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V1cXAlAx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IDvTydgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FmtrRN9K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c4nHc84p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gdT7kUgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n1abNBt5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1Ggolqdl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b9P11rfH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P38fMIts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CiDiC40V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BHXNhO4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iSCAKWHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GqCNfwHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CsSz3oPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JruOyihk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mdKcGvdY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MAIxrpW4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XlWlDX25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cwQc6XpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fx86YqFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2G9nertE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3tERJ14t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oXx12y6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1U15UwF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8QlwyZHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rPEJqZQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YlpFJSiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TIBsNhro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z0aZ2atb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_07btwmJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pz214iQP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UVq8w5qq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YuqPA4Gf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LNIqMcim_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MkvgkYNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lEFdaSsz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GbDNU5Zm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SQnNOalD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xAug9e88_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7KybwYnx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vAxoyE4w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ejonWryL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EF3Uujhm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ePXDQwO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_V9f0TRdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2hOk7HCO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HVUlJcxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ej3dZgtY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tbwoF3GF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CogRzFKa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_r03b2nio_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fpndxZGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zmJ0GJfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0vpNdUUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TW7rDMRQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NewI3M3W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bsVVJDuD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0hW4XRZr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pjNqFnKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_20rv40Dw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LYZyrAtC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_82wDGIaj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZumekpCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R9Tgs48Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KlecGffD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qOFuCc5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VmvhjxzT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6pjRR1YF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q0eIlDCb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gpVa0Nd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YZ0kSR0r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a4T0VghP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AlkADtAo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qo8R9zz3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F7TWhAvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X4DLzfVG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VwpNlafc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_erowoDUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ACqVW2Yd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pW5vi5WZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OjjWzc30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WcQ9FAfz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pTePS0A0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cR2Eb5TS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_COWigJXX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MIdd0fpf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4lNQ093x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GOrDQIlG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DFicNElS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CLkVLSdf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eWJKKU8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cSePVIs0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ExWPK0IO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q9nHv8Fy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ptpmbwSn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aLWRevQu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nzt2GwEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lyyHNwsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dIueXBC6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SAkV1siA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fQ5L1E7S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cBFTiEl7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dIoUmubc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WPTBmpw2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EaObbsny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pYL7zBoV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uaJ9TXTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XhTiTq2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6Wblo8PJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ny3rsnG5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_j3mzqjYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_F8K4wr9p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_e6fGwATq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5NstQogO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_coMbrFnq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dAN5hsQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aUr9pW1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YldLiiA8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vj49eGyq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Tt7cVVPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xPo2Vgxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LwLRUtgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wLmyhBYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LMxZgFwq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HDx1LxJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iDDnLolz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_C4gTOPzi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RruTJKNO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UyF4bv1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_C5OESs74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_A0Rv1fba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6zoDQklY_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_a5ZXB2RD;
  SignalLine sLine_m8JeNhex;
  SignalLine sLine_BJuzLR2I;
  SignalLine sLine_HuhqcwE4;
  SignalLine sLine_OzNQOz1v;
  SignalBiquad sBiquad_s_d0aahiJr;
  SignalLine sLine_aV7IjCPL;
  SignalLine sLine_X5SDehkX;
  SignalLine sLine_eNUBcmRk;
  SignalLine sLine_slZYDZdQ;
  SignalBiquad sBiquad_s_L4Uaqb42;
  SignalLine sLine_YHMmiQor;
  SignalLine sLine_yaH8SVke;
  SignalLine sLine_A03AgxcF;
  SignalLine sLine_hxI9kV28;
  SignalLine sLine_Vom5PUdQ;
  SignalBiquad sBiquad_s_e2K80Mif;
  SignalLine sLine_bwRQLtgO;
  SignalLine sLine_T8lpsQCa;
  SignalLine sLine_e9Swls7H;
  SignalLine sLine_1mYKJRJO;
  SignalLine sLine_epf2iekw;
  SignalBiquad sBiquad_s_4CcAFe6S;
  SignalLine sLine_pXrHX4nS;
  SignalLine sLine_nWoHz8Np;
  SignalLine sLine_KrPYhe9X;
  SignalLine sLine_TMG1tOYg;
  SignalBiquad sBiquad_s_lLhJEWzA;
  SignalLine sLine_2DRpoFAZ;
  SignalLine sLine_CgXX5HPU;
  SignalLine sLine_zrFaBecp;
  SignalLine sLine_mqOMPiDw;
  SignalLine sLine_dxOjaFrv;
  SignalBiquad sBiquad_s_VVHnvQOH;
  ControlVar cVar_BB0JP6Nw;
  ControlVar cVar_fhLSopdh;
  ControlVar cVar_QTPHIUsH;
  ControlVar cVar_Ev5WQv9v;
  ControlSlice cSlice_qFWS2DQ1;
  ControlVar cVar_Iti7Gp8n;
  ControlVar cVar_8TWyTIsp;
  ControlIf cIf_paeHwkrs;
  ControlIf cIf_ebvC0Yft;
  ControlBinop cBinop_3KOObcuf;
  ControlBinop cBinop_N7ma9iOr;
  ControlBinop cBinop_V3nZqMQL;
  ControlBinop cBinop_n7IFP61x;
  ControlBinop cBinop_LpWF5B37;
  ControlIf cIf_mcqJnVFJ;
  ControlBinop cBinop_dHnShe7E;
  ControlBinop cBinop_8BIOTvea;
  ControlBinop cBinop_0XjOc7co;
  ControlBinop cBinop_2Kh2MDc4;
  ControlBinop cBinop_1NttCOwx;
  ControlVar cVar_nKzrcsUn;
  ControlIf cIf_rlAXEQzd;
  ControlIf cIf_KLZFkt1M;
  ControlBinop cBinop_jUuXEKEy;
  ControlBinop cBinop_6L3Tk0YE;
  ControlBinop cBinop_jdegAp5U;
  ControlBinop cBinop_nZWaG0Sl;
  ControlBinop cBinop_BydsUveT;
  ControlIf cIf_55QvWWee;
  ControlBinop cBinop_z6NQAC5d;
  ControlBinop cBinop_vyXYoIYN;
  ControlBinop cBinop_Zx4KkGTL;
  ControlBinop cBinop_BYJMAfHA;
  ControlBinop cBinop_VJ8G2brR;
  ControlVar cVar_w76RQVkg;
  ControlIf cIf_qf3wgSSt;
  ControlIf cIf_tqHSGLZ3;
  ControlBinop cBinop_j5fw9CJP;
  ControlBinop cBinop_rWwsiybV;
  ControlBinop cBinop_UTBGq8H9;
  ControlBinop cBinop_mhGHSlvr;
  ControlBinop cBinop_or5sNQB5;
  ControlIf cIf_ZndBQzOg;
  ControlBinop cBinop_C3DDMJZc;
  ControlBinop cBinop_xsvvE6Dw;
  ControlBinop cBinop_q5s66UoS;
  ControlBinop cBinop_ajE05OjY;
  ControlBinop cBinop_iDii86CS;
  ControlIf cIf_9vJsYXoC;
  ControlSlice cSlice_5tsy2YPj;
  ControlVar cVar_s1H8ujZ7;
  ControlSlice cSlice_xU0cpkV3;
  ControlVar cVar_NXlncYPZ;
  ControlSlice cSlice_xS1w8T28;
  ControlVar cVar_Ti7mOwvT;
  ControlSlice cSlice_7ZCAFNUB;
  ControlVar cVar_iTDzfS37;
  ControlBinop cBinop_VCV6dM2n;
  ControlBinop cBinop_peodvNee;
  ControlBinop cBinop_cbRakVKc;
  ControlBinop cBinop_KUUCHe2X;
  ControlBinop cBinop_qCoaz7PQ;
  ControlBinop cBinop_a3q0Khzb;
  ControlBinop cBinop_QkUigYau;
  ControlBinop cBinop_jxquWIVg;
  ControlVar cVar_puIBsQpH;
  ControlBinop cBinop_grVZdjqO;
  ControlBinop cBinop_edmFDRgS;
  ControlBinop cBinop_aYVwncSG;
  ControlBinop cBinop_XfaR3cO8;
  ControlBinop cBinop_BnGmvL2w;
  ControlBinop cBinop_p94sIb4u;
  ControlBinop cBinop_YXXAhbet;
  ControlBinop cBinop_ekYMyycx;
  ControlVar cVar_5muw85Ng;
  ControlVar cVar_kDpc5wHy;
  ControlBinop cBinop_YkV5sRrf;
  ControlBinop cBinop_gPcbmv0t;
  ControlBinop cBinop_93f8W3gT;
  ControlBinop cBinop_YT4tON0n;
  ControlBinop cBinop_vfcGsZ2S;
  ControlBinop cBinop_PPjdmElh;
  ControlBinop cBinop_XIvnDMCm;
  ControlBinop cBinop_ZAUiKO9n;
  ControlBinop cBinop_wcUnj3Yn;
  ControlBinop cBinop_IevL1ztH;
  ControlBinop cBinop_Y7Q5T5FA;
  ControlBinop cBinop_rXTSkifS;
  ControlBinop cBinop_TxLQPW3t;
  ControlBinop cBinop_bklyk4SR;
  ControlBinop cBinop_wmztHwGW;
  ControlBinop cBinop_5RVCr3rI;
  ControlBinop cBinop_xSSGUxBq;
  ControlBinop cBinop_ncv591ow;
  ControlBinop cBinop_4ASbQY3G;
  ControlBinop cBinop_xgxzoAca;
  ControlVar cVar_YonuoeNU;
  ControlVar cVar_ueyIGSxm;
  ControlVar cVar_ddhwMrqS;
  ControlBinop cBinop_jTZLc66v;
  ControlBinop cBinop_x3gsY0Qy;
  ControlBinop cBinop_YTNKfl03;
  ControlBinop cBinop_s2bkk8e0;
  ControlBinop cBinop_K2uk7u7G;
  ControlBinop cBinop_dRpcNv16;
  ControlBinop cBinop_C7aLT0rm;
  ControlBinop cBinop_F1aEDSge;
  ControlBinop cBinop_fx8rLeIN;
  ControlBinop cBinop_vhxfj5Yp;
  ControlBinop cBinop_sYt1YgNC;
  ControlBinop cBinop_W5doq3iN;
  ControlBinop cBinop_X3YIfXV8;
  ControlBinop cBinop_rzt8lEAL;
  ControlBinop cBinop_GKsjYLmx;
  ControlBinop cBinop_QCKTM05K;
  ControlBinop cBinop_YZl0VoDH;
  ControlBinop cBinop_7d5waynl;
  ControlBinop cBinop_KJZmUQ2Z;
  ControlBinop cBinop_CmZl0two;
  ControlBinop cBinop_Ll1y2PHQ;
  ControlBinop cBinop_dOOgfClx;
  ControlBinop cBinop_ehOXRCiW;
  ControlVar cVar_1KQhFmsf;
  ControlVar cVar_fvzQWExC;
  ControlVar cVar_Fo67zrVh;
  ControlBinop cBinop_wRidfFLn;
  ControlBinop cBinop_JbwF3zBT;
  ControlBinop cBinop_DZ6DaeaI;
  ControlBinop cBinop_d2H4RdWj;
  ControlBinop cBinop_PEwhR6Kq;
  ControlBinop cBinop_Tbs4ApX4;
  ControlBinop cBinop_q1hoGURS;
  ControlBinop cBinop_RVV0dQdG;
  ControlBinop cBinop_iPvWaGzI;
  ControlBinop cBinop_K4tWkrXb;
  ControlBinop cBinop_keKi0m7g;
  ControlBinop cBinop_6GfcFtlE;
  SignalVarf sVarf_QATzjIpZ;
  SignalVarf sVarf_vmQ6kqPh;
  SignalVarf sVarf_90CLTkMM;
  ControlSlice cSlice_pCCBWG3n;
  ControlVar cVar_GstIRkRE;
  ControlVar cVar_AO7WGWUu;
  ControlIf cIf_kAPTUHUR;
  ControlIf cIf_2FXBUpQs;
  ControlBinop cBinop_wnp1zetI;
  ControlBinop cBinop_yKnaCbyw;
  ControlBinop cBinop_l4a0Vn2S;
  ControlBinop cBinop_ji2Ia90I;
  ControlBinop cBinop_Me5ZmU5x;
  ControlIf cIf_sAXUmLO1;
  ControlBinop cBinop_07arI7f4;
  ControlBinop cBinop_FGz6tUGS;
  ControlBinop cBinop_pjOAMOgh;
  ControlBinop cBinop_fO99uysc;
  ControlBinop cBinop_unOPrTf7;
  ControlVar cVar_MsddBMKH;
  ControlIf cIf_W16EAjpy;
  ControlIf cIf_Oke1MFkf;
  ControlBinop cBinop_dK4ccVMU;
  ControlBinop cBinop_dsyc77aR;
  ControlBinop cBinop_ngEp4TpG;
  ControlBinop cBinop_RdpWOGNS;
  ControlBinop cBinop_5p8aA6f9;
  ControlIf cIf_slicJiGb;
  ControlBinop cBinop_hwmlPeEP;
  ControlBinop cBinop_13x8J1XX;
  ControlBinop cBinop_VmHUe2NM;
  ControlBinop cBinop_wXJN9wZA;
  ControlBinop cBinop_2HVUvVse;
  ControlVar cVar_sopWmeTm;
  ControlIf cIf_roHKA6M9;
  ControlIf cIf_k2TyWfMg;
  ControlBinop cBinop_bfMPTqYJ;
  ControlBinop cBinop_bueAPoJF;
  ControlBinop cBinop_sAx0dcgm;
  ControlBinop cBinop_goIwB27V;
  ControlBinop cBinop_b9z7ycI4;
  ControlIf cIf_Ur48viSg;
  ControlBinop cBinop_in0K3npS;
  ControlBinop cBinop_IQZONn1q;
  ControlBinop cBinop_ZgWiSWAZ;
  ControlBinop cBinop_PJxQKi4a;
  ControlBinop cBinop_lcZRgEj3;
  ControlIf cIf_wrkSF9bh;
  ControlSlice cSlice_o54VlGTh;
  ControlVar cVar_IgJ9wh5E;
  ControlSlice cSlice_elAEH122;
  ControlVar cVar_G9OE8a55;
  ControlSlice cSlice_74SPRDJo;
  ControlVar cVar_xCMSN9Ih;
  ControlSlice cSlice_1yEFjZ9r;
  ControlVar cVar_5cCtaX1j;
  ControlBinop cBinop_N0aJ8teY;
  ControlBinop cBinop_UNDleA4k;
  ControlBinop cBinop_qy5461F5;
  ControlBinop cBinop_5R53mgWN;
  ControlBinop cBinop_6CyLorIb;
  ControlBinop cBinop_6R1KMUEo;
  ControlBinop cBinop_UopGuIto;
  ControlBinop cBinop_HojHfGnK;
  ControlVar cVar_ZD0IWTwI;
  ControlBinop cBinop_RJWn1Wcq;
  ControlBinop cBinop_r4SG2tIW;
  ControlBinop cBinop_zOvpUr1w;
  ControlBinop cBinop_zyakin4s;
  ControlBinop cBinop_1waI4bcL;
  ControlBinop cBinop_hHZ0kApF;
  ControlBinop cBinop_zgah5LHV;
  ControlBinop cBinop_gQTzEXHy;
  ControlVar cVar_BZVqZU9h;
  ControlVar cVar_ol1yy08i;
  ControlBinop cBinop_z1bzD1VI;
  ControlBinop cBinop_A99RM9qn;
  ControlBinop cBinop_yXJef9Rk;
  ControlBinop cBinop_bRpopLAG;
  ControlBinop cBinop_Jaawctk1;
  ControlBinop cBinop_JvJSpfRx;
  ControlBinop cBinop_LCc9HjJo;
  ControlBinop cBinop_zR6MhPDs;
  ControlBinop cBinop_Z9yXpz8y;
  ControlBinop cBinop_4Zrvatyt;
  ControlBinop cBinop_9o7cIUrA;
  ControlBinop cBinop_g9QYfcyF;
  ControlBinop cBinop_ryeIGNvs;
  ControlBinop cBinop_YDGc2Op0;
  ControlBinop cBinop_wDRRzTWx;
  ControlBinop cBinop_faNuLKx1;
  ControlBinop cBinop_Zgy6nCoI;
  ControlBinop cBinop_e33qDf3R;
  ControlBinop cBinop_6WaVr1Tt;
  ControlBinop cBinop_Mo84UlDG;
  ControlVar cVar_2hlHocoN;
  ControlVar cVar_0ZvHsNxO;
  ControlVar cVar_gO4zWVKS;
  ControlBinop cBinop_bJYqLAcv;
  ControlBinop cBinop_91L1OIiL;
  ControlBinop cBinop_kh3sxpq5;
  ControlBinop cBinop_V1cXAlAx;
  ControlBinop cBinop_IDvTydgk;
  ControlBinop cBinop_FmtrRN9K;
  ControlBinop cBinop_c4nHc84p;
  ControlBinop cBinop_gdT7kUgS;
  ControlBinop cBinop_oXx12y6l;
  ControlBinop cBinop_8QlwyZHx;
  ControlBinop cBinop_rPEJqZQI;
  ControlBinop cBinop_Z0aZ2atb;
  ControlBinop cBinop_07btwmJy;
  ControlBinop cBinop_pz214iQP;
  ControlBinop cBinop_UVq8w5qq;
  ControlBinop cBinop_YuqPA4Gf;
  ControlBinop cBinop_MkvgkYNJ;
  ControlBinop cBinop_GbDNU5Zm;
  ControlBinop cBinop_SQnNOalD;
  ControlBinop cBinop_7KybwYnx;
  ControlBinop cBinop_vAxoyE4w;
  ControlBinop cBinop_ejonWryL;
  ControlBinop cBinop_ePXDQwO9;
  ControlVar cVar_V9f0TRdB;
  ControlVar cVar_2hOk7HCO;
  ControlVar cVar_HVUlJcxw;
  ControlBinop cBinop_0vpNdUUP;
  ControlBinop cBinop_TW7rDMRQ;
  ControlBinop cBinop_NewI3M3W;
  ControlBinop cBinop_0hW4XRZr;
  ControlBinop cBinop_pjNqFnKl;
  ControlBinop cBinop_20rv40Dw;
  ControlBinop cBinop_LYZyrAtC;
  ControlBinop cBinop_82wDGIaj;
  ControlBinop cBinop_ZumekpCL;
  ControlBinop cBinop_Qo8R9zz3;
  ControlBinop cBinop_X4DLzfVG;
  ControlBinop cBinop_VwpNlafc;
  SignalVarf sVarf_LfGEk28F;
  SignalVarf sVarf_jVr2NT9G;
  SignalVarf sVarf_1I0SBK3l;
  ControlVar cVar_erowoDUu;
  ControlVar cVar_ACqVW2Yd;
  ControlBinop cBinop_COWigJXX;
  ControlBinop cBinop_MIdd0fpf;
  ControlBinop cBinop_4lNQ093x;
  ControlBinop cBinop_DFicNElS;
  ControlBinop cBinop_CLkVLSdf;
  ControlBinop cBinop_eWJKKU8b;
  ControlBinop cBinop_cSePVIs0;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
