/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_a5ZXB2RD);
  numBytes += sLine_init(&sLine_m8JeNhex);
  numBytes += sLine_init(&sLine_BJuzLR2I);
  numBytes += sLine_init(&sLine_HuhqcwE4);
  numBytes += sLine_init(&sLine_OzNQOz1v);
  numBytes += sBiquad_init(&sBiquad_s_d0aahiJr);
  numBytes += sLine_init(&sLine_aV7IjCPL);
  numBytes += sLine_init(&sLine_X5SDehkX);
  numBytes += sLine_init(&sLine_eNUBcmRk);
  numBytes += sLine_init(&sLine_slZYDZdQ);
  numBytes += sBiquad_init(&sBiquad_s_L4Uaqb42);
  numBytes += sLine_init(&sLine_YHMmiQor);
  numBytes += sLine_init(&sLine_yaH8SVke);
  numBytes += sLine_init(&sLine_A03AgxcF);
  numBytes += sLine_init(&sLine_hxI9kV28);
  numBytes += sLine_init(&sLine_Vom5PUdQ);
  numBytes += sBiquad_init(&sBiquad_s_e2K80Mif);
  numBytes += sLine_init(&sLine_bwRQLtgO);
  numBytes += sLine_init(&sLine_T8lpsQCa);
  numBytes += sLine_init(&sLine_e9Swls7H);
  numBytes += sLine_init(&sLine_1mYKJRJO);
  numBytes += sLine_init(&sLine_epf2iekw);
  numBytes += sBiquad_init(&sBiquad_s_4CcAFe6S);
  numBytes += sLine_init(&sLine_pXrHX4nS);
  numBytes += sLine_init(&sLine_nWoHz8Np);
  numBytes += sLine_init(&sLine_KrPYhe9X);
  numBytes += sLine_init(&sLine_TMG1tOYg);
  numBytes += sBiquad_init(&sBiquad_s_lLhJEWzA);
  numBytes += sLine_init(&sLine_2DRpoFAZ);
  numBytes += sLine_init(&sLine_CgXX5HPU);
  numBytes += sLine_init(&sLine_zrFaBecp);
  numBytes += sLine_init(&sLine_mqOMPiDw);
  numBytes += sLine_init(&sLine_dxOjaFrv);
  numBytes += sBiquad_init(&sBiquad_s_VVHnvQOH);
  numBytes += cVar_init_f(&cVar_BB0JP6Nw, 0.0f);
  numBytes += cVar_init_f(&cVar_fhLSopdh, 0.0f);
  numBytes += cVar_init_f(&cVar_QTPHIUsH, 0.0f);
  numBytes += cVar_init_f(&cVar_Ev5WQv9v, 0.0f);
  numBytes += cSlice_init(&cSlice_qFWS2DQ1, 1, -1);
  numBytes += cVar_init_f(&cVar_Iti7Gp8n, 1337.0f);
  numBytes += cVar_init_f(&cVar_8TWyTIsp, 0.0f);
  numBytes += cIf_init(&cIf_paeHwkrs, false);
  numBytes += cIf_init(&cIf_ebvC0Yft, false);
  numBytes += cBinop_init(&cBinop_3KOObcuf, 0.0f); // __pow
  numBytes += cIf_init(&cIf_mcqJnVFJ, false);
  numBytes += cBinop_init(&cBinop_0XjOc7co, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_2Kh2MDc4, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_1NttCOwx, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_nKzrcsUn, 0.0f);
  numBytes += cIf_init(&cIf_rlAXEQzd, false);
  numBytes += cIf_init(&cIf_KLZFkt1M, false);
  numBytes += cBinop_init(&cBinop_jUuXEKEy, 0.0f); // __pow
  numBytes += cIf_init(&cIf_55QvWWee, false);
  numBytes += cBinop_init(&cBinop_Zx4KkGTL, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_BYJMAfHA, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_VJ8G2brR, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_w76RQVkg, 0.0f);
  numBytes += cIf_init(&cIf_qf3wgSSt, false);
  numBytes += cIf_init(&cIf_tqHSGLZ3, false);
  numBytes += cBinop_init(&cBinop_j5fw9CJP, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ZndBQzOg, false);
  numBytes += cBinop_init(&cBinop_q5s66UoS, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ajE05OjY, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_iDii86CS, -15.0f); // __eq
  numBytes += cIf_init(&cIf_9vJsYXoC, false);
  numBytes += cSlice_init(&cSlice_5tsy2YPj, 1, -1);
  numBytes += cVar_init_f(&cVar_s1H8ujZ7, 0.0f);
  numBytes += cSlice_init(&cSlice_xU0cpkV3, 1, -1);
  numBytes += cVar_init_f(&cVar_NXlncYPZ, 0.0f);
  numBytes += cSlice_init(&cSlice_xS1w8T28, 1, -1);
  numBytes += cVar_init_f(&cVar_Ti7mOwvT, 0.0f);
  numBytes += cSlice_init(&cSlice_7ZCAFNUB, 1, -1);
  numBytes += cVar_init_f(&cVar_iTDzfS37, 0.313f);
  numBytes += cBinop_init(&cBinop_peodvNee, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_cbRakVKc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_puIBsQpH, 0.0f);
  numBytes += cVar_init_f(&cVar_5muw85Ng, 1337.0f);
  numBytes += cVar_init_f(&cVar_kDpc5wHy, 0.3f);
  numBytes += cBinop_init(&cBinop_gPcbmv0t, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vfcGsZ2S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PPjdmElh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XIvnDMCm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZAUiKO9n, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wcUnj3Yn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Y7Q5T5FA, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_rXTSkifS, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_YonuoeNU, 0.0f);
  numBytes += cVar_init_f(&cVar_ueyIGSxm, 1337.0f);
  numBytes += cVar_init_f(&cVar_ddhwMrqS, 0.313f);
  numBytes += cBinop_init(&cBinop_x3gsY0Qy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_K2uk7u7G, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dRpcNv16, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_C7aLT0rm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F1aEDSge, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vhxfj5Yp, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_sYt1YgNC, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1KQhFmsf, 0.0f);
  numBytes += cVar_init_f(&cVar_fvzQWExC, 1037.0f);
  numBytes += cVar_init_f(&cVar_Fo67zrVh, 0.4f);
  numBytes += cBinop_init(&cBinop_JbwF3zBT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PEwhR6Kq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Tbs4ApX4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_q1hoGURS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RVV0dQdG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iPvWaGzI, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_QATzjIpZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vmQ6kqPh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_90CLTkMM, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_pCCBWG3n, 1, -1);
  numBytes += cVar_init_f(&cVar_GstIRkRE, 1337.0f);
  numBytes += cVar_init_f(&cVar_AO7WGWUu, 0.0f);
  numBytes += cIf_init(&cIf_kAPTUHUR, false);
  numBytes += cIf_init(&cIf_2FXBUpQs, false);
  numBytes += cBinop_init(&cBinop_wnp1zetI, 0.0f); // __pow
  numBytes += cIf_init(&cIf_sAXUmLO1, false);
  numBytes += cBinop_init(&cBinop_pjOAMOgh, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_fO99uysc, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_unOPrTf7, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_MsddBMKH, 0.0f);
  numBytes += cIf_init(&cIf_W16EAjpy, false);
  numBytes += cIf_init(&cIf_Oke1MFkf, false);
  numBytes += cBinop_init(&cBinop_dK4ccVMU, 0.0f); // __pow
  numBytes += cIf_init(&cIf_slicJiGb, false);
  numBytes += cBinop_init(&cBinop_VmHUe2NM, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_wXJN9wZA, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2HVUvVse, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_sopWmeTm, 0.0f);
  numBytes += cIf_init(&cIf_roHKA6M9, false);
  numBytes += cIf_init(&cIf_k2TyWfMg, false);
  numBytes += cBinop_init(&cBinop_bfMPTqYJ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Ur48viSg, false);
  numBytes += cBinop_init(&cBinop_ZgWiSWAZ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_PJxQKi4a, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_lcZRgEj3, -15.0f); // __eq
  numBytes += cIf_init(&cIf_wrkSF9bh, false);
  numBytes += cSlice_init(&cSlice_o54VlGTh, 1, -1);
  numBytes += cVar_init_f(&cVar_IgJ9wh5E, 0.0f);
  numBytes += cSlice_init(&cSlice_elAEH122, 1, -1);
  numBytes += cVar_init_f(&cVar_G9OE8a55, 0.0f);
  numBytes += cSlice_init(&cSlice_74SPRDJo, 1, -1);
  numBytes += cVar_init_f(&cVar_xCMSN9Ih, 0.0f);
  numBytes += cSlice_init(&cSlice_1yEFjZ9r, 1, -1);
  numBytes += cVar_init_f(&cVar_5cCtaX1j, 0.313f);
  numBytes += cBinop_init(&cBinop_UNDleA4k, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_qy5461F5, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ZD0IWTwI, 0.0f);
  numBytes += cVar_init_f(&cVar_BZVqZU9h, 1337.0f);
  numBytes += cVar_init_f(&cVar_ol1yy08i, 0.3f);
  numBytes += cBinop_init(&cBinop_A99RM9qn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Jaawctk1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JvJSpfRx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LCc9HjJo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zR6MhPDs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Z9yXpz8y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9o7cIUrA, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_g9QYfcyF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2hlHocoN, 0.0f);
  numBytes += cVar_init_f(&cVar_0ZvHsNxO, 1337.0f);
  numBytes += cVar_init_f(&cVar_gO4zWVKS, 0.313f);
  numBytes += cBinop_init(&cBinop_91L1OIiL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IDvTydgk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FmtrRN9K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c4nHc84p, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gdT7kUgS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8QlwyZHx, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_rPEJqZQI, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_V9f0TRdB, 0.0f);
  numBytes += cVar_init_f(&cVar_2hOk7HCO, 1037.0f);
  numBytes += cVar_init_f(&cVar_HVUlJcxw, 0.4f);
  numBytes += cBinop_init(&cBinop_TW7rDMRQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pjNqFnKl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_20rv40Dw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LYZyrAtC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_82wDGIaj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZumekpCL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_LfGEk28F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jVr2NT9G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1I0SBK3l, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_erowoDUu, 5705.6f);
  numBytes += cVar_init_f(&cVar_ACqVW2Yd, 313.3f);
  numBytes += cBinop_init(&cBinop_COWigJXX, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_MIdd0fpf, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_4lNQ093x, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SAkV1siA_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cBFTiEl7_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fQ5L1E7S_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6zoDQklY_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EaObbsny_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pYL7zBoV_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dIoUmubc_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WPTBmpw2_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uaJ9TXTZ_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j3mzqjYs_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ny3rsnG5_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6Wblo8PJ_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5NstQogO_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e6fGwATq_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F8K4wr9p_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aUr9pW1n_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dAN5hsQL_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_coMbrFnq_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Tt7cVVPF_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xPo2Vgxx_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YldLiiA8_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vj49eGyq_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LwLRUtgS_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HDx1LxJR_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LMxZgFwq_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wLmyhBYo_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RruTJKNO_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C4gTOPzi_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iDDnLolz_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A0Rv1fba_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C5OESs74_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UyF4bv1s_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XhTiTq2m_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_BB0JP6Nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ExWPK0IO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_fhLSopdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q9nHv8Fy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_QTPHIUsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ptpmbwSn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Ev5WQv9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aLWRevQu_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cR2Eb5TS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pTePS0A0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WcQ9FAfz_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_6pn2A8zP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qFWS2DQ1, 0, m, &cSlice_qFWS2DQ1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_t4RQwi3x_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_qFWS2DQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BAY4Xx6C_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BAY4Xx6C_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Iti7Gp8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BAY4Xx6C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_BAY4Xx6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dIoUmubc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_8TWyTIsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dHnShe7E_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_paeHwkrs, 0, m, &cIf_paeHwkrs_sendMessage);
}

void Heavy_WSTD_3Q::cIf_paeHwkrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8BIOTvea_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_ebvC0Yft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MhEMc3QX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_n7IFP61x_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_e6TtqvBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3KOObcuf, HV_BINOP_POW, 0, m, &cBinop_3KOObcuf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3KOObcuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mcqJnVFJ, 0, m, &cIf_mcqJnVFJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_N7ma9iOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_LpWF5B37_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SrkykVPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_V3nZqMQL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tjJyKWR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ebvC0Yft, 0, m, &cIf_ebvC0Yft_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_V3nZqMQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ebvC0Yft, 1, m, &cIf_ebvC0Yft_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_n7IFP61x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_N7ma9iOr_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_MhEMc3QX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_mcqJnVFJ, 0, m, &cIf_mcqJnVFJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LpWF5B37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3KOObcuf, HV_BINOP_POW, 1, m, &cBinop_3KOObcuf_sendMessage);
  cMsg_e6TtqvBl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_mcqJnVFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_QATzjIpZ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_dHnShe7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_paeHwkrs, 1, m, &cIf_paeHwkrs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8BIOTvea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Kh2MDc4, HV_BINOP_GREATER_THAN, 1, m, &cBinop_2Kh2MDc4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1NttCOwx, HV_BINOP_EQ, 1, m, &cBinop_1NttCOwx_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_KPRxR4OR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0XjOc7co, HV_BINOP_ADD, 0, m, &cBinop_0XjOc7co_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0XjOc7co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SrkykVPM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tjJyKWR6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2Kh2MDc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mcqJnVFJ, 1, m, &cIf_mcqJnVFJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1NttCOwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mFmluKYJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_mFmluKYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QATzjIpZ, m);
}

void Heavy_WSTD_3Q::cCast_9voVsGbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8TWyTIsp, 0, m, &cVar_8TWyTIsp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VFvq76oZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KPRxR4OR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_kuWYlw7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0XjOc7co, HV_BINOP_ADD, 1, m, &cBinop_0XjOc7co_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Kh2MDc4, HV_BINOP_GREATER_THAN, 0, m, &cBinop_2Kh2MDc4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1NttCOwx, HV_BINOP_EQ, 0, m, &cBinop_1NttCOwx_sendMessage);
}

void Heavy_WSTD_3Q::cVar_nKzrcsUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_z6NQAC5d_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rlAXEQzd, 0, m, &cIf_rlAXEQzd_sendMessage);
}

void Heavy_WSTD_3Q::cIf_rlAXEQzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vyXYoIYN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_KLZFkt1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WePLN3ap_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_nZWaG0Sl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_02gwnt9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jUuXEKEy, HV_BINOP_POW, 0, m, &cBinop_jUuXEKEy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jUuXEKEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_55QvWWee, 0, m, &cIf_55QvWWee_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6L3Tk0YE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_BydsUveT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qFu1H8Sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jdegAp5U_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yWxC7pKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KLZFkt1M, 0, m, &cIf_KLZFkt1M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jdegAp5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KLZFkt1M, 1, m, &cIf_KLZFkt1M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nZWaG0Sl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_6L3Tk0YE_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_WePLN3ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_55QvWWee, 0, m, &cIf_55QvWWee_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BydsUveT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jUuXEKEy, HV_BINOP_POW, 1, m, &cBinop_jUuXEKEy_sendMessage);
  cMsg_02gwnt9u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_55QvWWee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_K4tWkrXb_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_keKi0m7g_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6GfcFtlE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_z6NQAC5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rlAXEQzd, 1, m, &cIf_rlAXEQzd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vyXYoIYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BYJMAfHA, HV_BINOP_GREATER_THAN, 1, m, &cBinop_BYJMAfHA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VJ8G2brR, HV_BINOP_EQ, 1, m, &cBinop_VJ8G2brR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_VkhFIC2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zx4KkGTL, HV_BINOP_ADD, 0, m, &cBinop_Zx4KkGTL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Zx4KkGTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qFu1H8Sz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yWxC7pKr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BYJMAfHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_55QvWWee, 1, m, &cIf_55QvWWee_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VJ8G2brR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YW8yMnkk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_YW8yMnkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_K4tWkrXb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_keKi0m7g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6GfcFtlE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PfIC279O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nKzrcsUn, 0, m, &cVar_nKzrcsUn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_w1PuNtEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VkhFIC2z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_Lgyfrjcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zx4KkGTL, HV_BINOP_ADD, 1, m, &cBinop_Zx4KkGTL_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BYJMAfHA, HV_BINOP_GREATER_THAN, 0, m, &cBinop_BYJMAfHA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VJ8G2brR, HV_BINOP_EQ, 0, m, &cBinop_VJ8G2brR_sendMessage);
}

void Heavy_WSTD_3Q::cVar_w76RQVkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_C3DDMJZc_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qf3wgSSt, 0, m, &cIf_qf3wgSSt_sendMessage);
}

void Heavy_WSTD_3Q::cIf_qf3wgSSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xsvvE6Dw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_tqHSGLZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_nU6mYYxX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mhGHSlvr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_RQKQWOP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_j5fw9CJP, HV_BINOP_POW, 0, m, &cBinop_j5fw9CJP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_j5fw9CJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZndBQzOg, 0, m, &cIf_ZndBQzOg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rWwsiybV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_or5sNQB5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rICsoGXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UTBGq8H9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aLjeiGpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tqHSGLZ3, 0, m, &cIf_tqHSGLZ3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UTBGq8H9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tqHSGLZ3, 1, m, &cIf_tqHSGLZ3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mhGHSlvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_rWwsiybV_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nU6mYYxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZndBQzOg, 0, m, &cIf_ZndBQzOg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_or5sNQB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j5fw9CJP, HV_BINOP_POW, 1, m, &cBinop_j5fw9CJP_sendMessage);
  cMsg_RQKQWOP8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_ZndBQzOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_90CLTkMM, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_C3DDMJZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qf3wgSSt, 1, m, &cIf_qf3wgSSt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xsvvE6Dw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ajE05OjY, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ajE05OjY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iDii86CS, HV_BINOP_EQ, 1, m, &cBinop_iDii86CS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_mCM0oMIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_q5s66UoS, HV_BINOP_ADD, 0, m, &cBinop_q5s66UoS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_q5s66UoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rICsoGXO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aLjeiGpg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ajE05OjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZndBQzOg, 1, m, &cIf_ZndBQzOg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iDii86CS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EJT8xIa2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_EJT8xIa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_90CLTkMM, m);
}

void Heavy_WSTD_3Q::cCast_juvUl71l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q5s66UoS, HV_BINOP_ADD, 1, m, &cBinop_q5s66UoS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ajE05OjY, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ajE05OjY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iDii86CS, HV_BINOP_EQ, 0, m, &cBinop_iDii86CS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HPnRkE7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w76RQVkg, 0, m, &cVar_w76RQVkg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KYvpdSUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mCM0oMIn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_9vJsYXoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_vmQ6kqPh, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_zsDpB7Tg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5tsy2YPj, 0, m, &cSlice_5tsy2YPj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RIm9WHQl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_5tsy2YPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZMyAA0Nu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZMyAA0Nu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_s1H8ujZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZMyAA0Nu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ZMyAA0Nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EaObbsny_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_RIm9WHQl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xU0cpkV3, 0, m, &cSlice_xU0cpkV3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6pn2A8zP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_xU0cpkV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7nAOPhq3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7nAOPhq3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_NXlncYPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7nAOPhq3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_7nAOPhq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uaJ9TXTZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_t4RQwi3x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xS1w8T28, 0, m, &cSlice_xS1w8T28_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kXU73YfK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_xS1w8T28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3pzpXfrs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3pzpXfrs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Ti7mOwvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3pzpXfrs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_3pzpXfrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pYL7zBoV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_kXU73YfK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7ZCAFNUB, 0, m, &cSlice_7ZCAFNUB_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_7ZCAFNUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JRVrIUER_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JRVrIUER_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_iTDzfS37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JRVrIUER_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_JRVrIUER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WPTBmpw2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_WkWhj9HN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a5ZXB2RD, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_kHeQKnRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m8JeNhex, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_kxHUagxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BJuzLR2I, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_rFPl1joS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HuhqcwE4, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_CwKBr5wI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OzNQOz1v, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_UyNTGetL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qk2VVR1y_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_qk2VVR1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_peodvNee, HV_BINOP_DIVIDE, 1, m, &cBinop_peodvNee_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MX52visa_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_OV1QImLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_VCV6dM2n_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_cSsZDlnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_OV1QImLD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VCV6dM2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_peodvNee, HV_BINOP_DIVIDE, 0, m, &cBinop_peodvNee_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MX52visa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cSsZDlnI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_peodvNee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbRakVKc, HV_BINOP_MULTIPLY, 1, m, &cBinop_cbRakVKc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cbRakVKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UTWJiret_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bexLDlLM_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_bStcGBVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EghjHVQn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_RatXEQmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Cgl28Xox_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_KUUCHe2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_qCoaz7PQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qCoaz7PQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbRakVKc, HV_BINOP_MULTIPLY, 0, m, &cBinop_cbRakVKc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a3q0Khzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_QkUigYau_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QkUigYau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KYvlK4xE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jxquWIVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_puIBsQpH, 1, m, &cVar_puIBsQpH_sendMessage);
}

void Heavy_WSTD_3Q::cVar_puIBsQpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_USqblY4k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_grVZdjqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vfcGsZ2S, HV_BINOP_MULTIPLY, 1, m, &cBinop_vfcGsZ2S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_edmFDRgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_grVZdjqO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aYVwncSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XfaR3cO8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XfaR3cO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PPjdmElh, HV_BINOP_MULTIPLY, 1, m, &cBinop_PPjdmElh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BnGmvL2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XIvnDMCm, HV_BINOP_MULTIPLY, 1, m, &cBinop_XIvnDMCm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_p94sIb4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BnGmvL2w_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YXXAhbet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZAUiKO9n, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZAUiKO9n_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Co1JiI5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ekYMyycx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ekYMyycx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wcUnj3Yn, HV_BINOP_MULTIPLY, 1, m, &cBinop_wcUnj3Yn_sendMessage);
}

void Heavy_WSTD_3Q::cVar_5muw85Ng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mi1QstDZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_KUUCHe2X_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VfmjWf1N_sendMessage);
}

void Heavy_WSTD_3Q::cVar_kDpc5wHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_a3q0Khzb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UTWJiret_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_bStcGBVv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bexLDlLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_RatXEQmW_sendMessage);
}

void Heavy_WSTD_3Q::cSend_EghjHVQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6Wblo8PJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Cgl28Xox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ny3rsnG5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_alGSqSnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_j3mzqjYs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_KYvlK4xE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YkV5sRrf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YkV5sRrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gPcbmv0t, HV_BINOP_MULTIPLY, 1, m, &cBinop_gPcbmv0t_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gPcbmv0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_93f8W3gT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_93f8W3gT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_alGSqSnk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_USqblY4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YT4tON0n_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YT4tON0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DulOxjfW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZLpTNqKP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3Pps5J4a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SUgyRgmN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DAOvudPG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WBb7qTzW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vfcGsZ2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WkWhj9HN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PPjdmElh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kHeQKnRu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_XIvnDMCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kxHUagxh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ZAUiKO9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rFPl1joS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_wcUnj3Yn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CwKBr5wI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_oyTIXFxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kDpc5wHy, 1, m, &cVar_kDpc5wHy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_o25CJBCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5muw85Ng, 0, m, &cVar_5muw85Ng_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WBb7qTzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vfcGsZ2S, HV_BINOP_MULTIPLY, 0, m, &cBinop_vfcGsZ2S_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3Pps5J4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZAUiKO9n, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZAUiKO9n_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DAOvudPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PPjdmElh, HV_BINOP_MULTIPLY, 0, m, &cBinop_PPjdmElh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZLpTNqKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wcUnj3Yn, HV_BINOP_MULTIPLY, 0, m, &cBinop_wcUnj3Yn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SUgyRgmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XIvnDMCm, HV_BINOP_MULTIPLY, 0, m, &cBinop_XIvnDMCm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DulOxjfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_VfmjWf1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_puIBsQpH, 0, m, &cVar_puIBsQpH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Mi1QstDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kDpc5wHy, 0, m, &cVar_kDpc5wHy_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lLPrln45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aV7IjCPL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_5PR7m6L5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X5SDehkX, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MdP9W2RT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eNUBcmRk, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_R3Nvz9Cd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_slZYDZdQ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_foLzZOIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nlaPLtiy_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_nlaPLtiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y7Q5T5FA, HV_BINOP_DIVIDE, 1, m, &cBinop_Y7Q5T5FA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MHzHM3VG_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Jz3NjMO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_IevL1ztH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_WFPEzQZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Jz3NjMO4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IevL1ztH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y7Q5T5FA, HV_BINOP_DIVIDE, 0, m, &cBinop_Y7Q5T5FA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MHzHM3VG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WFPEzQZK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Y7Q5T5FA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rXTSkifS, HV_BINOP_MULTIPLY, 1, m, &cBinop_rXTSkifS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rXTSkifS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PyInXu4k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3wfH1587_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_AEjWaokl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MYcayndF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_516QChLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7RFkO3rH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_TxLQPW3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_bklyk4SR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bklyk4SR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rXTSkifS, HV_BINOP_MULTIPLY, 0, m, &cBinop_rXTSkifS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wmztHwGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_5RVCr3rI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5RVCr3rI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rSDvy0Uj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xSSGUxBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dRpcNv16, HV_BINOP_MULTIPLY, 1, m, &cBinop_dRpcNv16_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ncv591ow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YonuoeNU, 1, m, &cVar_YonuoeNU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4ASbQY3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C7aLT0rm, HV_BINOP_MULTIPLY, 1, m, &cBinop_C7aLT0rm_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_5iw15YyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xgxzoAca_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xgxzoAca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F1aEDSge, HV_BINOP_MULTIPLY, 1, m, &cBinop_F1aEDSge_sendMessage);
}

void Heavy_WSTD_3Q::cVar_YonuoeNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3xqeelRw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_ueyIGSxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_itR0jaDd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_TxLQPW3t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P7UDywDP_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ddhwMrqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wmztHwGW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3wfH1587_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_516QChLI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PyInXu4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_AEjWaokl_sendMessage);
}

void Heavy_WSTD_3Q::cSend_MYcayndF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F8K4wr9p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_7RFkO3rH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e6fGwATq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_34HoSDDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5NstQogO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_rSDvy0Uj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jTZLc66v_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jTZLc66v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x3gsY0Qy, HV_BINOP_MULTIPLY, 1, m, &cBinop_x3gsY0Qy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_x3gsY0Qy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YTNKfl03_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YTNKfl03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_34HoSDDg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_3xqeelRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_s2bkk8e0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_s2bkk8e0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RDmVbZbu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2pmAaALB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xs2XzYZc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PNeXM6AD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_K2uk7u7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lLPrln45_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_dRpcNv16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5PR7m6L5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_C7aLT0rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MdP9W2RT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_F1aEDSge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R3Nvz9Cd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_KRGikCEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ddhwMrqS, 1, m, &cVar_ddhwMrqS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6f2P9hzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ueyIGSxm, 0, m, &cVar_ueyIGSxm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_itR0jaDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ddhwMrqS, 0, m, &cVar_ddhwMrqS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_P7UDywDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YonuoeNU, 0, m, &cVar_YonuoeNU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Xs2XzYZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dRpcNv16, HV_BINOP_MULTIPLY, 0, m, &cBinop_dRpcNv16_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2pmAaALB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C7aLT0rm, HV_BINOP_MULTIPLY, 0, m, &cBinop_C7aLT0rm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PNeXM6AD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K2uk7u7G, HV_BINOP_MULTIPLY, 0, m, &cBinop_K2uk7u7G_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RDmVbZbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F1aEDSge, HV_BINOP_MULTIPLY, 0, m, &cBinop_F1aEDSge_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Q00iL2Vv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YHMmiQor, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_sd4mIOSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yaH8SVke, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_B84trSHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_A03AgxcF, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_pSUzovqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hxI9kV28, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_dbkijxjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vom5PUdQ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_EeLAMP0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WH9JeiqB_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_WH9JeiqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vhxfj5Yp, HV_BINOP_DIVIDE, 1, m, &cBinop_vhxfj5Yp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ROR8t6SQ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Ftg0hdLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fx8rLeIN_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_2of2u6gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Ftg0hdLC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fx8rLeIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vhxfj5Yp, HV_BINOP_DIVIDE, 0, m, &cBinop_vhxfj5Yp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ROR8t6SQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2of2u6gp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vhxfj5Yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sYt1YgNC, HV_BINOP_MULTIPLY, 1, m, &cBinop_sYt1YgNC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sYt1YgNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B2eVSfZA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gZrEuUcF_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_1k21HgEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Lpvmtq4R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_DtFNSR28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Vd5qBP6E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_W5doq3iN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_X3YIfXV8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_X3YIfXV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sYt1YgNC, HV_BINOP_MULTIPLY, 0, m, &cBinop_sYt1YgNC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rzt8lEAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_GKsjYLmx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GKsjYLmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OEJUfafN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_QCKTM05K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PEwhR6Kq, HV_BINOP_MULTIPLY, 1, m, &cBinop_PEwhR6Kq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_g60vPSSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YZl0VoDH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YZl0VoDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QCKTM05K_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_5bHhNlGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7d5waynl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7d5waynl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tbs4ApX4, HV_BINOP_MULTIPLY, 1, m, &cBinop_Tbs4ApX4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KJZmUQ2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q1hoGURS, HV_BINOP_MULTIPLY, 1, m, &cBinop_q1hoGURS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ijUmO8Px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CmZl0two_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CmZl0two_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KJZmUQ2Z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ll1y2PHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1KQhFmsf, 1, m, &cVar_1KQhFmsf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dOOgfClx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RVV0dQdG, HV_BINOP_MULTIPLY, 1, m, &cBinop_RVV0dQdG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zxRbpREP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ehOXRCiW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ehOXRCiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iPvWaGzI, HV_BINOP_MULTIPLY, 1, m, &cBinop_iPvWaGzI_sendMessage);
}

void Heavy_WSTD_3Q::cVar_1KQhFmsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g3dBtEgo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_fvzQWExC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6JQnKTNy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_W5doq3iN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6QqPKXIv_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Fo67zrVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_rzt8lEAL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_B2eVSfZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_1k21HgEi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gZrEuUcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_DtFNSR28_sendMessage);
}

void Heavy_WSTD_3Q::cSend_Lpvmtq4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_coMbrFnq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Vd5qBP6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dAN5hsQL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_j8yEDq1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aUr9pW1n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_OEJUfafN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wRidfFLn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wRidfFLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JbwF3zBT, HV_BINOP_MULTIPLY, 1, m, &cBinop_JbwF3zBT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JbwF3zBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DZ6DaeaI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DZ6DaeaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_j8yEDq1X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_g3dBtEgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_d2H4RdWj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_d2H4RdWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KxODAI8Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6blOP0JJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BSbvYfz3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cgCP9Gxa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3h0B465A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IXobMh1R_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PEwhR6Kq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q00iL2Vv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Tbs4ApX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sd4mIOSF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_q1hoGURS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B84trSHx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_RVV0dQdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pSUzovqZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_iPvWaGzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dbkijxjY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_KDY9KDZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fvzQWExC, 0, m, &cVar_fvzQWExC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Eo4mSVQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fo67zrVh, 1, m, &cVar_Fo67zrVh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BSbvYfz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RVV0dQdG, HV_BINOP_MULTIPLY, 0, m, &cBinop_RVV0dQdG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3h0B465A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tbs4ApX4, HV_BINOP_MULTIPLY, 0, m, &cBinop_Tbs4ApX4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6blOP0JJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iPvWaGzI, HV_BINOP_MULTIPLY, 0, m, &cBinop_iPvWaGzI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cgCP9Gxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q1hoGURS, HV_BINOP_MULTIPLY, 0, m, &cBinop_q1hoGURS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KxODAI8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_IXobMh1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PEwhR6Kq, HV_BINOP_MULTIPLY, 0, m, &cBinop_PEwhR6Kq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6QqPKXIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1KQhFmsf, 0, m, &cVar_1KQhFmsf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6JQnKTNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fo67zrVh, 0, m, &cVar_Fo67zrVh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_K4tWkrXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9vJsYXoC, 1, m, &cIf_9vJsYXoC_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_AI0Ufx84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vmQ6kqPh, m);
}

void Heavy_WSTD_3Q::cBinop_keKi0m7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AI0Ufx84_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6GfcFtlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9vJsYXoC, 0, m, &cIf_9vJsYXoC_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_t4qetpRc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pCCBWG3n, 0, m, &cSlice_pCCBWG3n_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9NqkFmbS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_pCCBWG3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_A6KQz1nW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_A6KQz1nW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_GstIRkRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A6KQz1nW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_A6KQz1nW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YldLiiA8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_AO7WGWUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_07arI7f4_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_kAPTUHUR, 0, m, &cIf_kAPTUHUR_sendMessage);
}

void Heavy_WSTD_3Q::cIf_kAPTUHUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FGz6tUGS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_2FXBUpQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_eiVvRr6B_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ji2Ia90I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_Dhrfri8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wnp1zetI, HV_BINOP_POW, 0, m, &cBinop_wnp1zetI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wnp1zetI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sAXUmLO1, 0, m, &cIf_sAXUmLO1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yKnaCbyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Me5ZmU5x_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TZZmRhXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2FXBUpQs, 0, m, &cIf_2FXBUpQs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6fYFLwWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_l4a0Vn2S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_l4a0Vn2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2FXBUpQs, 1, m, &cIf_2FXBUpQs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ji2Ia90I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yKnaCbyw_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_eiVvRr6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_sAXUmLO1, 0, m, &cIf_sAXUmLO1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Me5ZmU5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wnp1zetI, HV_BINOP_POW, 1, m, &cBinop_wnp1zetI_sendMessage);
  cMsg_Dhrfri8a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_sAXUmLO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_LfGEk28F, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_07arI7f4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kAPTUHUR, 1, m, &cIf_kAPTUHUR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FGz6tUGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fO99uysc, HV_BINOP_GREATER_THAN, 1, m, &cBinop_fO99uysc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_unOPrTf7, HV_BINOP_EQ, 1, m, &cBinop_unOPrTf7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_GNA0zXFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pjOAMOgh, HV_BINOP_ADD, 0, m, &cBinop_pjOAMOgh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pjOAMOgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6fYFLwWS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TZZmRhXq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fO99uysc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sAXUmLO1, 1, m, &cIf_sAXUmLO1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_unOPrTf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CS59JooV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_CS59JooV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LfGEk28F, m);
}

void Heavy_WSTD_3Q::cCast_pWFx2WjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AO7WGWUu, 0, m, &cVar_AO7WGWUu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3CzghXcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GNA0zXFb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_PYesE5j4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pjOAMOgh, HV_BINOP_ADD, 1, m, &cBinop_pjOAMOgh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fO99uysc, HV_BINOP_GREATER_THAN, 0, m, &cBinop_fO99uysc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_unOPrTf7, HV_BINOP_EQ, 0, m, &cBinop_unOPrTf7_sendMessage);
}

void Heavy_WSTD_3Q::cVar_MsddBMKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hwmlPeEP_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_W16EAjpy, 0, m, &cIf_W16EAjpy_sendMessage);
}

void Heavy_WSTD_3Q::cIf_W16EAjpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_13x8J1XX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_Oke1MFkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QQNdvl8x_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_RdpWOGNS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_tYyEf4cP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dK4ccVMU, HV_BINOP_POW, 0, m, &cBinop_dK4ccVMU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dK4ccVMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_slicJiGb, 0, m, &cIf_slicJiGb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dsyc77aR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_5p8aA6f9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_e5gaKPJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Oke1MFkf, 0, m, &cIf_Oke1MFkf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kywEHqLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ngEp4TpG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ngEp4TpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Oke1MFkf, 1, m, &cIf_Oke1MFkf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RdpWOGNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dsyc77aR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_QQNdvl8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_slicJiGb, 0, m, &cIf_slicJiGb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5p8aA6f9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dK4ccVMU, HV_BINOP_POW, 1, m, &cBinop_dK4ccVMU_sendMessage);
  cMsg_tYyEf4cP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_slicJiGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Qo8R9zz3_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_X4DLzfVG_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_VwpNlafc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_hwmlPeEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W16EAjpy, 1, m, &cIf_W16EAjpy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_13x8J1XX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wXJN9wZA, HV_BINOP_GREATER_THAN, 1, m, &cBinop_wXJN9wZA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2HVUvVse, HV_BINOP_EQ, 1, m, &cBinop_2HVUvVse_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_HYcIDU6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VmHUe2NM, HV_BINOP_ADD, 0, m, &cBinop_VmHUe2NM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VmHUe2NM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kywEHqLo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e5gaKPJ3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wXJN9wZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_slicJiGb, 1, m, &cIf_slicJiGb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2HVUvVse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WzsQvwk8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_WzsQvwk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Qo8R9zz3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_X4DLzfVG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_VwpNlafc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_C0oLjv1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VmHUe2NM, HV_BINOP_ADD, 1, m, &cBinop_VmHUe2NM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wXJN9wZA, HV_BINOP_GREATER_THAN, 0, m, &cBinop_wXJN9wZA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2HVUvVse, HV_BINOP_EQ, 0, m, &cBinop_2HVUvVse_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jS2Zp3OJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MsddBMKH, 0, m, &cVar_MsddBMKH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hdPx7RCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HYcIDU6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_sopWmeTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_in0K3npS_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_roHKA6M9, 0, m, &cIf_roHKA6M9_sendMessage);
}

void Heavy_WSTD_3Q::cIf_roHKA6M9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IQZONn1q_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_k2TyWfMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_buRj5c35_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_goIwB27V_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_ffbLk1RN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bfMPTqYJ, HV_BINOP_POW, 0, m, &cBinop_bfMPTqYJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bfMPTqYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ur48viSg, 0, m, &cIf_Ur48viSg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bueAPoJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_b9z7ycI4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZIxA2tmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k2TyWfMg, 0, m, &cIf_k2TyWfMg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_N9vepiKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sAx0dcgm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sAx0dcgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k2TyWfMg, 1, m, &cIf_k2TyWfMg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_goIwB27V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_bueAPoJF_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_buRj5c35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Ur48viSg, 0, m, &cIf_Ur48viSg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_b9z7ycI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bfMPTqYJ, HV_BINOP_POW, 1, m, &cBinop_bfMPTqYJ_sendMessage);
  cMsg_ffbLk1RN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_Ur48viSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_1I0SBK3l, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_in0K3npS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_roHKA6M9, 1, m, &cIf_roHKA6M9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IQZONn1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PJxQKi4a, HV_BINOP_GREATER_THAN, 1, m, &cBinop_PJxQKi4a_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lcZRgEj3, HV_BINOP_EQ, 1, m, &cBinop_lcZRgEj3_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_RcEhMT3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZgWiSWAZ, HV_BINOP_ADD, 0, m, &cBinop_ZgWiSWAZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZgWiSWAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N9vepiKX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZIxA2tmj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PJxQKi4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ur48viSg, 1, m, &cIf_Ur48viSg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lcZRgEj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5J6iinp2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_5J6iinp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1I0SBK3l, m);
}

void Heavy_WSTD_3Q::cCast_WkX9kgNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RcEhMT3m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_QacSvONm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZgWiSWAZ, HV_BINOP_ADD, 1, m, &cBinop_ZgWiSWAZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PJxQKi4a, HV_BINOP_GREATER_THAN, 0, m, &cBinop_PJxQKi4a_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lcZRgEj3, HV_BINOP_EQ, 0, m, &cBinop_lcZRgEj3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ouoJ7IA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sopWmeTm, 0, m, &cVar_sopWmeTm_sendMessage);
}

void Heavy_WSTD_3Q::cIf_wrkSF9bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_jVr2NT9G, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_R8sS3XrI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_o54VlGTh, 0, m, &cSlice_o54VlGTh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1euHBnpz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_o54VlGTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JG4MMtkk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JG4MMtkk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_IgJ9wh5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JG4MMtkk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_JG4MMtkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Tt7cVVPF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_1euHBnpz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_elAEH122, 0, m, &cSlice_elAEH122_sendMessage);
      break;
    }
    default: {
      cSwitchcase_t4qetpRc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_elAEH122_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mfQdcfnE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mfQdcfnE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_G9OE8a55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mfQdcfnE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_mfQdcfnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LwLRUtgS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_9NqkFmbS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_74SPRDJo, 0, m, &cSlice_74SPRDJo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZRXwf9Zc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_74SPRDJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Gp5uQk9b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Gp5uQk9b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_xCMSN9Ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Gp5uQk9b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Gp5uQk9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xPo2Vgxx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_ZRXwf9Zc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1yEFjZ9r, 0, m, &cSlice_1yEFjZ9r_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_1yEFjZ9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4u6e12ar_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4u6e12ar_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_5cCtaX1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4u6e12ar_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_4u6e12ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vj49eGyq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_yfxDfJ2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bwRQLtgO, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_GlaP3VsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T8lpsQCa, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xS8IZq5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e9Swls7H, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_aft7nbXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1mYKJRJO, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_HFD9fbJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_epf2iekw, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_AcnAAEHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TWOYyJG8_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_TWOYyJG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UNDleA4k, HV_BINOP_DIVIDE, 1, m, &cBinop_UNDleA4k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mjMQ6z4B_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_hpQBWSpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_N0aJ8teY_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_NIKD0Bjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_hpQBWSpT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_N0aJ8teY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UNDleA4k, HV_BINOP_DIVIDE, 0, m, &cBinop_UNDleA4k_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mjMQ6z4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NIKD0Bjc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UNDleA4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qy5461F5, HV_BINOP_MULTIPLY, 1, m, &cBinop_qy5461F5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qy5461F5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UQ379Pue_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rtVK20Rs_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_GmwGwTXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Wt08C07y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_iCxwBcXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iKRhgUWJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_5R53mgWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6CyLorIb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6CyLorIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qy5461F5, HV_BINOP_MULTIPLY, 0, m, &cBinop_qy5461F5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6R1KMUEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_UopGuIto_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UopGuIto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sxz0e2e9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_HojHfGnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZD0IWTwI, 1, m, &cVar_ZD0IWTwI_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ZD0IWTwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A5y6779A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_RJWn1Wcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jaawctk1, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jaawctk1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r4SG2tIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RJWn1Wcq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zOvpUr1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_zyakin4s_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zyakin4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JvJSpfRx, HV_BINOP_MULTIPLY, 1, m, &cBinop_JvJSpfRx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1waI4bcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LCc9HjJo, HV_BINOP_MULTIPLY, 1, m, &cBinop_LCc9HjJo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hHZ0kApF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1waI4bcL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zgah5LHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zR6MhPDs, HV_BINOP_MULTIPLY, 1, m, &cBinop_zR6MhPDs_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_g6uRnAzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gQTzEXHy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gQTzEXHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z9yXpz8y, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z9yXpz8y_sendMessage);
}

void Heavy_WSTD_3Q::cVar_BZVqZU9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kLbXaott_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_5R53mgWN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JmzMJuyb_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ol1yy08i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6R1KMUEo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UQ379Pue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_GmwGwTXN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rtVK20Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_iCxwBcXF_sendMessage);
}

void Heavy_WSTD_3Q::cSend_Wt08C07y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wLmyhBYo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_iKRhgUWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LMxZgFwq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_zG5qIPVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HDx1LxJR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Sxz0e2e9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_z1bzD1VI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z1bzD1VI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A99RM9qn, HV_BINOP_MULTIPLY, 1, m, &cBinop_A99RM9qn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_A99RM9qn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yXJef9Rk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yXJef9Rk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zG5qIPVs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_A5y6779A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bRpopLAG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bRpopLAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1FpMruBr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GtzHCqQz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wO5AT3v3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BxRdrddP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_umsEixI4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wfnJH2eB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Jaawctk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yfxDfJ2U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_JvJSpfRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GlaP3VsE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LCc9HjJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xS8IZq5X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_zR6MhPDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aft7nbXF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Z9yXpz8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HFD9fbJi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_y5ZckQ96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BZVqZU9h, 0, m, &cVar_BZVqZU9h_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NcQWEOhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ol1yy08i, 1, m, &cVar_ol1yy08i_sendMessage);
}

void Heavy_WSTD_3Q::cCast_umsEixI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JvJSpfRx, HV_BINOP_MULTIPLY, 0, m, &cBinop_JvJSpfRx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GtzHCqQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z9yXpz8y, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z9yXpz8y_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BxRdrddP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LCc9HjJo, HV_BINOP_MULTIPLY, 0, m, &cBinop_LCc9HjJo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1FpMruBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_wfnJH2eB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jaawctk1, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jaawctk1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wO5AT3v3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zR6MhPDs, HV_BINOP_MULTIPLY, 0, m, &cBinop_zR6MhPDs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kLbXaott_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ol1yy08i, 0, m, &cVar_ol1yy08i_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JmzMJuyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZD0IWTwI, 0, m, &cVar_ZD0IWTwI_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Tnwhru76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pXrHX4nS, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_qps8kAsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nWoHz8Np, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_TXpoxYK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KrPYhe9X, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_wyF5LWgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TMG1tOYg, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_iIBsJlGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cvsMdzpw_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_cvsMdzpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9o7cIUrA, HV_BINOP_DIVIDE, 1, m, &cBinop_9o7cIUrA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lUNT4PhC_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_JMFCi2LS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_4Zrvatyt_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_iU1WFYNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_JMFCi2LS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4Zrvatyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9o7cIUrA, HV_BINOP_DIVIDE, 0, m, &cBinop_9o7cIUrA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lUNT4PhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iU1WFYNv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9o7cIUrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g9QYfcyF, HV_BINOP_MULTIPLY, 1, m, &cBinop_g9QYfcyF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_g9QYfcyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kl1Vefm8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ToZB1YKY_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_4LqAD9cO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SkdXNZGU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_4vQ5V7P3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6TBT06PP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ryeIGNvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_YDGc2Op0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YDGc2Op0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g9QYfcyF, HV_BINOP_MULTIPLY, 0, m, &cBinop_g9QYfcyF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wDRRzTWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_faNuLKx1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_faNuLKx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AQDDEjRy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Zgy6nCoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FmtrRN9K, HV_BINOP_MULTIPLY, 1, m, &cBinop_FmtrRN9K_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_e33qDf3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2hlHocoN, 1, m, &cVar_2hlHocoN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6WaVr1Tt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c4nHc84p, HV_BINOP_MULTIPLY, 1, m, &cBinop_c4nHc84p_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lQGcOHVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Mo84UlDG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Mo84UlDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdT7kUgS, HV_BINOP_MULTIPLY, 1, m, &cBinop_gdT7kUgS_sendMessage);
}

void Heavy_WSTD_3Q::cVar_2hlHocoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qiRtAgbk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_0ZvHsNxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b9P11rfH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ryeIGNvs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P38fMIts_sendMessage);
}

void Heavy_WSTD_3Q::cVar_gO4zWVKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wDRRzTWx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ToZB1YKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_4vQ5V7P3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kl1Vefm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_4LqAD9cO_sendMessage);
}

void Heavy_WSTD_3Q::cSend_SkdXNZGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iDDnLolz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_6TBT06PP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_C4gTOPzi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_z1GALwbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RruTJKNO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_AQDDEjRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bJYqLAcv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bJYqLAcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_91L1OIiL, HV_BINOP_MULTIPLY, 1, m, &cBinop_91L1OIiL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_91L1OIiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kh3sxpq5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kh3sxpq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z1GALwbX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_qiRtAgbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_V1cXAlAx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_V1cXAlAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GqCNfwHM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BHXNhO4R_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CiDiC40V_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iSCAKWHe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IDvTydgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tnwhru76_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FmtrRN9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qps8kAsf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_c4nHc84p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TXpoxYK2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_gdT7kUgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wyF5LWgd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_n1abNBt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gO4zWVKS, 1, m, &cVar_gO4zWVKS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1Ggolqdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0ZvHsNxO, 0, m, &cVar_0ZvHsNxO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_b9P11rfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gO4zWVKS, 0, m, &cVar_gO4zWVKS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_P38fMIts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2hlHocoN, 0, m, &cVar_2hlHocoN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CiDiC40V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FmtrRN9K, HV_BINOP_MULTIPLY, 0, m, &cBinop_FmtrRN9K_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BHXNhO4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c4nHc84p, HV_BINOP_MULTIPLY, 0, m, &cBinop_c4nHc84p_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iSCAKWHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IDvTydgk, HV_BINOP_MULTIPLY, 0, m, &cBinop_IDvTydgk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GqCNfwHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdT7kUgS, HV_BINOP_MULTIPLY, 0, m, &cBinop_gdT7kUgS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_CsSz3oPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2DRpoFAZ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_JruOyihk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CgXX5HPU, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_mdKcGvdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zrFaBecp, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MAIxrpW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mqOMPiDw, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_XlWlDX25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dxOjaFrv, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_cwQc6XpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fx86YqFn_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_fx86YqFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8QlwyZHx, HV_BINOP_DIVIDE, 1, m, &cBinop_8QlwyZHx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1U15UwF9_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_2G9nertE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_oXx12y6l_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3tERJ14t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_2G9nertE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oXx12y6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8QlwyZHx, HV_BINOP_DIVIDE, 0, m, &cBinop_8QlwyZHx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1U15UwF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3tERJ14t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_8QlwyZHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rPEJqZQI, HV_BINOP_MULTIPLY, 1, m, &cBinop_rPEJqZQI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rPEJqZQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tbwoF3GF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ej3dZgtY_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_YlpFJSiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CogRzFKa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_TIBsNhro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_r03b2nio_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Z0aZ2atb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_07btwmJy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_07btwmJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rPEJqZQI, HV_BINOP_MULTIPLY, 0, m, &cBinop_rPEJqZQI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pz214iQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_UVq8w5qq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UVq8w5qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zmJ0GJfu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YuqPA4Gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pjNqFnKl, HV_BINOP_MULTIPLY, 1, m, &cBinop_pjNqFnKl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_LNIqMcim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MkvgkYNJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MkvgkYNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YuqPA4Gf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lEFdaSsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_GbDNU5Zm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GbDNU5Zm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20rv40Dw, HV_BINOP_MULTIPLY, 1, m, &cBinop_20rv40Dw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SQnNOalD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LYZyrAtC, HV_BINOP_MULTIPLY, 1, m, &cBinop_LYZyrAtC_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_xAug9e88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7KybwYnx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7KybwYnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SQnNOalD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vAxoyE4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V9f0TRdB, 1, m, &cVar_V9f0TRdB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ejonWryL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_82wDGIaj, HV_BINOP_MULTIPLY, 1, m, &cBinop_82wDGIaj_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_EF3Uujhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ePXDQwO9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ePXDQwO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZumekpCL, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZumekpCL_sendMessage);
}

void Heavy_WSTD_3Q::cVar_V9f0TRdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bsVVJDuD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_2hOk7HCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AlkADtAo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Z0aZ2atb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a4T0VghP_sendMessage);
}

void Heavy_WSTD_3Q::cVar_HVUlJcxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_pz214iQP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ej3dZgtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_TIBsNhro_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tbwoF3GF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_YlpFJSiv_sendMessage);
}

void Heavy_WSTD_3Q::cSend_CogRzFKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UyF4bv1s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_r03b2nio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_C5OESs74_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_fpndxZGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A0Rv1fba_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_zmJ0GJfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0vpNdUUP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0vpNdUUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TW7rDMRQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_TW7rDMRQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TW7rDMRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NewI3M3W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NewI3M3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fpndxZGK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_bsVVJDuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0hW4XRZr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0hW4XRZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q0eIlDCb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VmvhjxzT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YZ0kSR0r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6pjRR1YF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qOFuCc5w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gpVa0Nd7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pjNqFnKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CsSz3oPN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_20rv40Dw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JruOyihk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LYZyrAtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mdKcGvdY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_82wDGIaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MAIxrpW4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ZumekpCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XlWlDX25_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_R9Tgs48Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2hOk7HCO, 0, m, &cVar_2hOk7HCO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KlecGffD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HVUlJcxw, 1, m, &cVar_HVUlJcxw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qOFuCc5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20rv40Dw, HV_BINOP_MULTIPLY, 0, m, &cBinop_20rv40Dw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VmvhjxzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZumekpCL, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZumekpCL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6pjRR1YF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LYZyrAtC, HV_BINOP_MULTIPLY, 0, m, &cBinop_LYZyrAtC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_q0eIlDCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_gpVa0Nd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pjNqFnKl, HV_BINOP_MULTIPLY, 0, m, &cBinop_pjNqFnKl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YZ0kSR0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_82wDGIaj, HV_BINOP_MULTIPLY, 0, m, &cBinop_82wDGIaj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_a4T0VghP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V9f0TRdB, 0, m, &cVar_V9f0TRdB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AlkADtAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HVUlJcxw, 0, m, &cVar_HVUlJcxw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Qo8R9zz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wrkSF9bh, 1, m, &cIf_wrkSF9bh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_F7TWhAvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jVr2NT9G, m);
}

void Heavy_WSTD_3Q::cBinop_X4DLzfVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F7TWhAvP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_VwpNlafc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wrkSF9bh, 0, m, &cIf_wrkSF9bh_sendMessage);
}

void Heavy_WSTD_3Q::cVar_erowoDUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MIdd0fpf, HV_BINOP_DIVIDE, 0, m, &cBinop_MIdd0fpf_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ACqVW2Yd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_COWigJXX, HV_BINOP_DIVIDE, 1, m, &cBinop_COWigJXX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MIdd0fpf, HV_BINOP_DIVIDE, 1, m, &cBinop_MIdd0fpf_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_pW5vi5WZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4lNQ093x, HV_BINOP_DIVIDE, 0, m, &cBinop_4lNQ093x_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_OjjWzc30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4lNQ093x, HV_BINOP_DIVIDE, 1, m, &cBinop_4lNQ093x_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WcQ9FAfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_COWigJXX, HV_BINOP_DIVIDE, 0, m, &cBinop_COWigJXX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_pTePS0A0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_erowoDUu, 0, m, &cVar_erowoDUu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cR2Eb5TS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ACqVW2Yd, 0, m, &cVar_ACqVW2Yd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_COWigJXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_pW5vi5WZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MIdd0fpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_OjjWzc30_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4lNQ093x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_CLkVLSdf_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_GOrDQIlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_cSePVIs0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DFicNElS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_eWJKKU8b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CLkVLSdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_DFicNElS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eWJKKU8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_GOrDQIlG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cSePVIs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nzt2GwEp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ExWPK0IO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zsDpB7Tg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R8sS3XrI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Q9nHv8Fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zsDpB7Tg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R8sS3XrI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ptpmbwSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zsDpB7Tg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R8sS3XrI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_aLWRevQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zsDpB7Tg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R8sS3XrI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_nzt2GwEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zsDpB7Tg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_R8sS3XrI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_lyyHNwsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Ev5WQv9v, 0, m, &cVar_Ev5WQv9v_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_dIueXBC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_BB0JP6Nw, 0, m, &cVar_BB0JP6Nw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fhLSopdh, 0, m, &cVar_fhLSopdh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QTPHIUsH, 0, m, &cVar_QTPHIUsH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_SAkV1siA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BB0JP6Nw, 0, m, &cVar_BB0JP6Nw_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_fQ5L1E7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fhLSopdh, 0, m, &cVar_fhLSopdh_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_cBFTiEl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QTPHIUsH, 0, m, &cVar_QTPHIUsH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dIoUmubc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ueyIGSxm, 0, m, &cVar_ueyIGSxm_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_WPTBmpw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KRGikCEJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6f2P9hzl_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_EaObbsny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9voVsGbB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kuWYlw7z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VFvq76oZ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_pYL7zBoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HPnRkE7r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_juvUl71l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KYvpdSUv_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_uaJ9TXTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PfIC279O_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lgyfrjcz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w1PuNtEF_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_XhTiTq2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UyNTGetL_sendMessage(_c, 0, m);
  cMsg_foLzZOIs_sendMessage(_c, 0, m);
  cMsg_EeLAMP0S_sendMessage(_c, 0, m);
  cMsg_AcnAAEHW_sendMessage(_c, 0, m);
  cMsg_iIBsJlGl_sendMessage(_c, 0, m);
  cMsg_cwQc6XpA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5muw85Ng, 0, m, &cVar_5muw85Ng_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ueyIGSxm, 0, m, &cVar_ueyIGSxm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fvzQWExC, 0, m, &cVar_fvzQWExC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BZVqZU9h, 0, m, &cVar_BZVqZU9h_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0ZvHsNxO, 0, m, &cVar_0ZvHsNxO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2hOk7HCO, 0, m, &cVar_2hOk7HCO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Iti7Gp8n, 0, m, &cVar_Iti7Gp8n_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8TWyTIsp, 0, m, &cVar_8TWyTIsp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nKzrcsUn, 0, m, &cVar_nKzrcsUn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w76RQVkg, 0, m, &cVar_w76RQVkg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s1H8ujZ7, 0, m, &cVar_s1H8ujZ7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NXlncYPZ, 0, m, &cVar_NXlncYPZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ti7mOwvT, 0, m, &cVar_Ti7mOwvT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iTDzfS37, 0, m, &cVar_iTDzfS37_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GstIRkRE, 0, m, &cVar_GstIRkRE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AO7WGWUu, 0, m, &cVar_AO7WGWUu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MsddBMKH, 0, m, &cVar_MsddBMKH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sopWmeTm, 0, m, &cVar_sopWmeTm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IgJ9wh5E, 0, m, &cVar_IgJ9wh5E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_G9OE8a55, 0, m, &cVar_G9OE8a55_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xCMSN9Ih, 0, m, &cVar_xCMSN9Ih_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5cCtaX1j, 0, m, &cVar_5cCtaX1j_sendMessage);
  cMsg_dIueXBC6_sendMessage(_c, 0, m);
  cMsg_lyyHNwsl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_6Wblo8PJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gPcbmv0t, HV_BINOP_MULTIPLY, 0, m, &cBinop_gPcbmv0t_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ny3rsnG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_edmFDRgS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aYVwncSG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_p94sIb4u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_YXXAhbet_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_j3mzqjYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jxquWIVg_sendMessage);
  cMsg_Co1JiI5C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_F8K4wr9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x3gsY0Qy, HV_BINOP_MULTIPLY, 0, m, &cBinop_x3gsY0Qy_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_e6fGwATq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_4ASbQY3G_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_5NstQogO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K2uk7u7G, HV_BINOP_MULTIPLY, 1, m, &cBinop_K2uk7u7G_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xSSGUxBq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ncv591ow_sendMessage);
  cMsg_5iw15YyZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_coMbrFnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JbwF3zBT, HV_BINOP_MULTIPLY, 0, m, &cBinop_JbwF3zBT_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dAN5hsQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g60vPSSr_sendMessage(_c, 0, m);
  cMsg_5bHhNlGQ_sendMessage(_c, 0, m);
  cMsg_ijUmO8Px_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_dOOgfClx_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_aUr9pW1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ll1y2PHQ_sendMessage);
  cMsg_zxRbpREP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_YldLiiA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0ZvHsNxO, 0, m, &cVar_0ZvHsNxO_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_vj49eGyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n1abNBt5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1Ggolqdl_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Tt7cVVPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pWFx2WjZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PYesE5j4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3CzghXcw_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_xPo2Vgxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ouoJ7IA8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QacSvONm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WkX9kgNf_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_LwLRUtgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jS2Zp3OJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C0oLjv1h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hdPx7RCy_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_wLmyhBYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A99RM9qn, HV_BINOP_MULTIPLY, 0, m, &cBinop_A99RM9qn_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_LMxZgFwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_r4SG2tIW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zOvpUr1w_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_hHZ0kApF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_zgah5LHV_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_HDx1LxJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HojHfGnK_sendMessage);
  cMsg_g6uRnAzp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_iDDnLolz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_91L1OIiL, HV_BINOP_MULTIPLY, 0, m, &cBinop_91L1OIiL_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_C4gTOPzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_6WaVr1Tt_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_RruTJKNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IDvTydgk, HV_BINOP_MULTIPLY, 1, m, &cBinop_IDvTydgk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Zgy6nCoI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_e33qDf3R_sendMessage);
  cMsg_lQGcOHVW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_UyF4bv1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TW7rDMRQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_TW7rDMRQ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_C5OESs74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LNIqMcim_sendMessage(_c, 0, m);
  cMsg_lEFdaSsz_sendMessage(_c, 0, m);
  cMsg_xAug9e88_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ejonWryL_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_A0Rv1fba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vAxoyE4w_sendMessage);
  cMsg_EF3Uujhm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_6zoDQklY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ev5WQv9v, 0, m, &cVar_Ev5WQv9v_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_a5ZXB2RD, VOf(Bf0));
    __hv_line_f(&sLine_m8JeNhex, VOf(Bf1));
    __hv_line_f(&sLine_BJuzLR2I, VOf(Bf2));
    __hv_line_f(&sLine_HuhqcwE4, VOf(Bf3));
    __hv_line_f(&sLine_OzNQOz1v, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_d0aahiJr, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_QATzjIpZ, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_aV7IjCPL, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_X5SDehkX, VOf(Bf1));
    __hv_line_f(&sLine_eNUBcmRk, VOf(Bf0));
    __hv_line_f(&sLine_slZYDZdQ, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_L4Uaqb42, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_vmQ6kqPh, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_YHMmiQor, VOf(Bf5));
    __hv_line_f(&sLine_yaH8SVke, VOf(Bf1));
    __hv_line_f(&sLine_A03AgxcF, VOf(Bf2));
    __hv_line_f(&sLine_hxI9kV28, VOf(Bf4));
    __hv_line_f(&sLine_Vom5PUdQ, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_e2K80Mif, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_90CLTkMM, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_bwRQLtgO, VOf(Bf6));
    __hv_line_f(&sLine_T8lpsQCa, VOf(Bf2));
    __hv_line_f(&sLine_e9Swls7H, VOf(Bf1));
    __hv_line_f(&sLine_1mYKJRJO, VOf(Bf5));
    __hv_line_f(&sLine_epf2iekw, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_4CcAFe6S, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_LfGEk28F, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_pXrHX4nS, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_nWoHz8Np, VOf(Bf2));
    __hv_line_f(&sLine_KrPYhe9X, VOf(Bf6));
    __hv_line_f(&sLine_TMG1tOYg, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_lLhJEWzA, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_jVr2NT9G, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_2DRpoFAZ, VOf(Bf8));
    __hv_line_f(&sLine_CgXX5HPU, VOf(Bf2));
    __hv_line_f(&sLine_zrFaBecp, VOf(Bf1));
    __hv_line_f(&sLine_mqOMPiDw, VOf(Bf7));
    __hv_line_f(&sLine_dxOjaFrv, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_VVHnvQOH, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_1I0SBK3l, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
